%define	name	parted
%define	version	1.4.9
%define	release	1
%define	prefix	/usr
%define	sbindir	%{prefix}/sbin

Summary:	flexible partitioning tool
Name:		%{name}
Version:	%{version}
Release:	%{release}
Copyright:	GPL
Group:		Applications/System
Vendor:		Andrew Clausen <clausen@gnu.org>
URL:		http://www.gnu.org/software/parted
Source:		ftp://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.gz
Buildroot:	%{_tmppath}/%{name}-%{version}-root
Requires:	e2fsprogs
BuildPrereq:	e2fsprogs-devel
Conflicts:	%{name} < 1.2.0

%description
GNU Parted is a program that allows you to create, destroy,
resize, move and copy hard disk partitions. This is useful for
creating space for new operating systems, reorganising disk
usage, and copying data to new hard disks.

%package	devel
Summary:	files required to compile software that uses libparted
Group:		Development/System
Requires:	e2fsprogs
BuildPrereq:	e2fsprogs-devel
Conflicts:	%{name}-devel < 1.2.0

%description	devel
This package includes the header files and libraries needed to
statically link software with libparted.

%package	boot
Summary:	flexible partitioning tool
Group:		Applications/System
Requires:	e2fsprogs
BuildPrereq:	e2fsprogs-devel
Conflicts:	%{name}-boot < 1.2.0

%description	boot
This package includes a stripped down version of parted that can be used
as part of a boot/rescue disk.

This is just the binary. Renamed to parted-boot.

%prep
%setup -q

%build
# Build boot version first.
export CFLAGS="${RPM_OPT_FLAGS}";
./configure --prefix=%{prefix} --sbindir=%{sbindir} \
	--without-readline --disable-nls --disable-shared --enable-all-static
make
mv parted/parted parted/parted-boot;

# DistClean to insure clean build of normal version.
make distclean
export CFLAGS="${RPM_OPT_FLAGS}";
./configure --prefix=%{prefix} --sbindir=%{sbindir}
make

%install
[ -d ${RPM_BUILD_ROOT} ] && rm -rf ${RPM_BUILD_ROOT};
make prefix=${RPM_BUILD_ROOT}%{prefix} sbindir=${RPM_BUILD_ROOT}%{sbindir} install
strip ${RPM_BUILD_ROOT}%{sbindir}/parted

install -s -m 755 parted/parted-boot ${RPM_BUILD_ROOT}%{sbindir}

# Prep for rpm docs
cp ABOUT-NLS AUTHORS BUGS COPYING ChangeLog INSTALL NEWS README THANKS TODO doc
rm doc/Make*

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%clean
[ -d ${RPM_BUILD_ROOT} ] && rm -rf ${RPM_BUILD_ROOT};

%files
%defattr(-,root,root)
%doc doc/*
%{sbindir}/parted
%{prefix}/lib/libparted.so*
%{prefix}/share/locale/*/LC_MESSAGES/*
%{prefix}/man/man8/parted.8*

%files devel
%defattr(-,root,root)
%{prefix}/include/parted
%{prefix}/lib/libparted.a
%{prefix}/share/aclocal/parted.m4

%files boot
%defattr(-,root,root)
%{sbindir}/parted-boot

%changelog
* Tue Feb 20 2001 Ryan Weaver <ryanw@infohwy.com>
  [parted-1.4.9-1]
- new ja.po
- new USER.jp
- ext2_mkfs() and swap_write() doesn't zero out the first block.
  useful for Sun...
- fixed bsd_partition_align() - checks if the intersection of
  two constraints exists, before trying to find a solution.
- updated doc/USER, wrt CHS/LBA, etc.
- fixed ext2 mkfs code: the lost+found inode gets create/modify/access
  time time (NULL), rather than 1969 ;-)
- fixed fat: changed FatCluster from __s32 to __u32.  Arghh.

* Mon Feb  5 2001 Ryan Weaver <ryanw@infohwy.com>
  [parted-1.4.8-1]
- added Sun regression tests
- fixed (hacked) disk_dos.c and disk_bsd.c, so *_partition_set_flag()
  always pass an fs_type != NULL to ped_partition_set_system()
- added partition flags for Sun disk labels
- more hacking on Sun stuff
- added Sun disk label support (thanks Ben!)
- added UFS probe/clobber support (thanks Ben!)
- added PED_DEVICE_FILE support (as opposed to going through
- we now require autoconf 2.49b to build configure from configure.in,
  because it provides the new AC_CHECK_SIZEOF
- use new AC_CHECK_SIZEOF for off_t.
- changed configure.in to match the new AC_CHECK_TYPE
- hacked libtool.m4 (!)... I hope this all gets fixed properly, soon..
- tried to make libparted/device.c more portable
- libparted/fs_fat/bootsector.h - fixed the size of the FAT16 part of
  the union... needed an extra byte in boot_code.  (purely aesthetic ;-)

* Tue Jan 16 2001 Ryan Weaver <ryanw@infohwy.com>
  [parted-1.4.7-1]
- fixed ped_file_system_clobber() - wasn't leaving/fetching
  exceptions properly
- fixed _calc_min_logical_start() - was horribly broken.
  Only affects the new work-around for "cylinder not aligned", etc.
- don't try to guess the geometry for a second time...
  (introduced geom_already_guessed to PedDevice)
- ext2_mkfs now enables file-type by default.
- ped_partition_new() (not DISK_partition_new()) calls
  ped_partition_set_system() now. Makes sure it calls
  ped_partition_set_system() for extended partitions too!
- added documentation for ped_file_system_clobber()
- fixed semantics for ped_file_system_clobber() - they need
  to change, since ped_file_system_probe() is different...

* Mon Jan  8 2001 Ryan Weaver <ryanw@infohwy.com>
  [parted-1.4.6-1]
- msdos_partition_new() if there is no file system passed, sets
  the system to 0x83. 0 is a bad choice, because it means it isn't
  a partition. It's an even worse choice, because it will make
  msdos_probe() fail.
- "partition not aligned" workaround (similar to that in 1.2.x)
- uses dgettext (PACKAGE, ...) instead of gettext (...). Updated
  API docs, to reflect this (for ped_partition_flag_get_name(), etc.)
- released 1.4.6-pre1
- fixed brain-dead bug, dealing with min_geom in _primary_constraint()
  in libparted/disk_dos.c
- released 1.4.6-pre2 (internally)
- fixed another bug (out-by-one, in _primary_constraint(), again)
- added bindtextdomain() to ped_init()
- removed that annoying "Parted's boot loader" message
- ped_file_system_probe() now attempts ped_file_system_open(), if
  there is any ambiguouity
- mac_clobber() now nukes the partition map as well ;-)

* Fri Dec 29 2000 Ryan Weaver <ryanw@infohwy.com>
  [parted-1.4.5-1]
- documented PedConstraint and PedAlignment (doc/API)
- made incompatible change to API: changed ped_constraint_exact()
  now takes a PedGeometry, not a PedPartition (what was I thinking?!)
- the bug fix in 1.4.5-pre3 (wrap-around bug) was wrong. Fixed
  properly now.
- made the FAT16 <-> FAT32 conversion messages more friendly
- ext2_mkfs() now makes sparse file systems by default
- rearranged ext2_mkfs() a bit, and separated generation of the
  super block
- fixed bug in ext2_mkfs(): if there isn't enough room for per-group
  metadata in the last block group, then chop it off!
- fixed ext2 bug in ext2_is_data_block() in ext2.h. I forgot to
  endian-awarenize (?) it!!!
- FAT resizer now avoids changing the fat type (FAT16 or FAT32)
  in script mode
- removed error checking, after the "point of no return" in the
  FAT resizer
- updated documentation, adding info about FAT16 <-> FAT32, and
  boot loaders
- fixed nasty wrap-around bug in fat_construct_directory()
  and fat_convert_directory(), when directories have their last
  cluster/sector filled.
- merged in FAT32 boot loader fix (now copies the "hidden sectors")
- merge FAT fix from 1.2.14-pre1
- Apple_Free partitions have status 0x0 (not 0x33)
- fixed _ext2_get_resize_constraint(). constraint->min_size was
  calculated in (ext2) blocks, not 512 byte sectors. (patch from
  Matt Wilson)
- commented out "this is not a block device", because it already
  warns about "this is not SCSI/IDE", etc.
- added another example to the documentation
- made the "unable to align partition" error message a bit more
  understandable, and allow the problem to be ignored.
- added an assertion to ext2_is_data_block(), to make sure the block
  is in the file-system.
- added a note about "make install-libs" for e2fsprogs

* Thu Nov 30 2000 Ryan Weaver <ryanw@infohwy.com>
  [parted-1.4.4-1]
- fixed a brain-dead bug in ext2_meta.c:109. This bug causes
  growth of ext2 all file systems, that require more GDT blocks
  to get corrupted!!! OUCH!!!
- fixed regression tests, to test GDT growth
- ped_device_add() adds to the end now
- added a check in /proc/partitions for devices
- added error checking to both versions doinode(). Hmmm, do I like
  this idea of 2 doinode()'s?
- finalized the copyright assignments, and now we can get rid of
  lots of annoying bureaucracy (read: s/Andrew Clausen, Lennert
  .../Free Softw.../g)
- changed "cp FROM-MINOR [TO-DEVICE] TO-MINOR" to
  "cp [FROM-DEVICE] FROM-MINOR TO-MINOR"

* Fri Nov 24 2000 Ryan Weaver <ryanw@infohwy.com>
  [parted-1.4.3-1]
- added ped_file_system_clobber_exclude(), and resize/copy now use it.
- fixed hfs_clobber() and reiserfs_clobber()

* Sun Nov 19 2000 Ryan Weaver <ryanw@infohwy.com>
  [parted-1.4.2-1]
- fixed a few mistakes in doc/USER (thanks Stefan!)
- now uses the en_US locale for numbers. (quick fix, because the
  "lexer" isn't properly i18nized yet - I'll fix this properly
  next week, because I intend to do Major Surgery TM on the
  command parser anyway). Basic problem is: the lexer says a
  number is [0-9.]+, but in Europe, s/\./,/.
- loop-back is now probed last.
- removed dependance on <linux/fs.h>
- discovered that type-casts have high precedence. oops.
  s/(long) EXPR/(long) (EXPR)/, which fixes seg faults on PPC.

* Wed Nov 15 2000 Ryan Weaver <ryanw@infohwy.com>
  [parted-1.4.1-1]
- added read-only support (useful for disk imaging from CD-ROMs)
- changed default behaviour to warnings such as "not a block device" (in
  libparted/device.c) to PED_EXCEPTION_IGNORE.
- removed the scary "development version only TM" message.  OOPS!

* Mon Nov 13 2000 Ryan Weaver <ryanw@infohwy.com>
  [parted-1.4.0-1]
- added ./configure --enable-all-static
- mac_partition_new() now sets the name to "untitled".
- added an assertion, that the disk has the PED_DISK_TYPE_EXTENDED
  feature, for extended partitions, in ped_partition_new()
- file systems only get ped_file_system_clobber()'d if mkfs is
  supported for that fs
- fixed hfs_probe()
- fixed some bugs with the mac_partition_align() stuff
- cleaned the doc/USER a bit more
- Mac bug fixes & reorganisation
- mac_partition_align() - greedily takes up free space now, if it
  is consistent with the constraints.
- set policy for _partition_align() - must be in update mode. Changed
  other functions to meet this.
- fixed a stupid bug introduced in 1.4.0-pre6, in libparted/disk_dos.c,
  read_table() Was passing a pointer to a pointer of a constraint,
  as opposed to the pointer.
- much hacking on Mac support
- fixed a bug in libparted/disk_mac.c, that broke mkpart*.
  In mac_partition_new(), it was checking for failure, but missed out the '!'.
- commented out the linux-swap Linux 2.0 warning. It annoys more users
  than it helps.
- hacked around the mac-boot & no-HFS problem, by setting the file system
  temporarily, in mac_partition_set_system() (YUCK!)
- applied a patch from Masahiro Sakai <ZVM01052@nifty.ne.jp>. Now uses
  mbs* as opposed to iconv. That fixes lots of brokeness, but there may
  be problems for utf-8 users... but this will be solved by gettext in future.
- fixed the annoying linux-swap on mac bug (it was trying to set the
  swap flag, before setting the partition type to linux-swap, which
  caused the Mac disk label code to complain)
- fixed a bug in ped_constraint_solve_nearest() - errr to complicated
  to explain - easier to look at the diff. Basically: I wasn't taking
  the intersection of the allowable start and end ranges properly,
  WRT min_start.
- removed some memory leaks from libparted/disk_dos.c, around the
  constraint stuff.
- fixed boot flag stuff for Mac
- docs have been massively updated (ages ago...)
- merged in changes to 1.2.10-pre3 (notably: malloc() debugging, and
  all the bugs / leaks fixed as a result ;-)
- added ped_disk_remove_partition()
- mac fixes: writes new signature now, s/Apple_Unix/Apple_UNIX/g
- reiserfs_probe() - doesn't probe outside of the partition any more ;-)
- lots of work on API docs
- added a bit to the documentation about how to deal with the boot disk,
  when it doesn't support your hardware

